/****************************************************************************
* Simple XML-based UI builder for Qt4
* Copyright (C) 2007-2012 Michał Męciński
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*   1. Redistributions of source code must retain the above copyright notice,
*      this list of conditions and the following disclaimer.
*   2. Redistributions in binary form must reproduce the above copyright
*      notice, this list of conditions and the following disclaimer in the
*      documentation and/or other materials provided with the distribution.
*   3. Neither the name of the copyright holder nor the names of the
*      contributors may be used to endorse or promote products derived from
*      this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
****************************************************************************/

#include "mainwindow.h"

#include <QAction>
#include <QApplication>
#include <QFileDialog>
#include <QMessageBox>

#include "iconloader.h"
#include "textview.h"
#include "xmlui/toolstrip.h"

MainWindow::MainWindow()
{
    setWindowTitle( tr( "XMLUI Demo" ) );

    QAction* action;

    action = new QAction( IconLoader::icon( "new" ), tr( "New" ), this );
    connect( action, SIGNAL( triggered() ), this, SLOT( newFile() ) );
    setAction( "newFile", action );

    action = new QAction( IconLoader::icon( "open" ), tr( "Open..." ), this );
    action->setShortcut( QKeySequence::Open );
    connect( action, SIGNAL( triggered() ), this, SLOT( openFile() ) );
    setAction( "openFile", action );

    action = new QAction( IconLoader::icon( "close" ), tr( "Close" ), this );
    connect( action, SIGNAL( triggered() ), this, SLOT( closeFile() ) );
    setAction( "closeFile", action );

    setTitle( "sectionFile", tr( "File" ) );

    loadXmlUiFile( ":/resources/mainwindow.xml" );

    XmlUi::ToolStrip* strip = new XmlUi::ToolStrip( this );
    setMenuWidget( strip );

    XmlUi::Builder* builder = new XmlUi::Builder( this );
    builder->registerToolStrip( "stripMain", strip );
    builder->addClient( this );

    resize( 600, 400 );
}

MainWindow::~MainWindow()
{
}

void MainWindow::newFile()
{
    closeFile();

    TextView* view = new TextView( this );
    setCentralWidget( view );

    builder()->addClient( view );

    builder()->toolStrip( "stripMain" )->addAuxiliaryAction( action( "closeFile" ) );
}

void MainWindow::openFile()
{
    QString path = QFileDialog::getOpenFileName( this, tr( "Open File" ) );

    if ( !path.isEmpty() ) {
        closeFile();

        TextView* view = new TextView( this, path );
        setCentralWidget( view );

        builder()->addClient( view );

        builder()->toolStrip( "stripMain" )->addAuxiliaryAction( action( "closeFile" ) );
    }
}

void MainWindow::closeFile()
{
    QWidget* view = centralWidget();

    if ( view != NULL ) {
        delete view;

        builder()->toolStrip( "stripMain" )->clearAuxiliaryActions();
    }
}
